[hide private]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pyxmpp2: PyXMPP2 is a Python implementation of the XMPP protocol (RFC 6120, RFC 6121) and some of XMPP Extensions
  - pyxmpp2.binding: Resource binding implementation.
  - pyxmpp2.client: Basic XMPP-IM client implementation.
  - pyxmpp2.clientstream: Client-Server stream handling.
  - pyxmpp2.constants: Common XMPP constants.
  - pyxmpp2.error: XMPP error handling.
  - pyxmpp2.etree: ElementTree API selection.
  - pyxmpp2.exceptions: PyXMPP exceptions.
  - pyxmpp2.expdict: Dictionary with item expiration.
  - pyxmpp2.interfaces: Base interfaces of PyXMPP2.
  - pyxmpp2.iq: Iq XMPP stanza handling
  - pyxmpp2.jid: jid -- XMPP address handling
  - pyxmpp2.mainloop: PyXMPP main event loop - the event and I/O framework, aka re-inventing the wheel.
    - pyxmpp2.mainloop.base: Main loop implementation Base.
    - pyxmpp2.mainloop.events: PyXMPP events.
    - pyxmpp2.mainloop.interfaces: Abstract base classes for the main loop framework.
    - pyxmpp2.mainloop.poll: I/O Handling classes
    - pyxmpp2.mainloop.select: I/O Handling classes
    - pyxmpp2.mainloop.threads: I/O Handling classes
    - pyxmpp2.mainloop.wait: Utility functions to wait until a socket (or object implementing .fileno() in POSIX) is ready for input or output.
  - pyxmpp2.message: Message XMPP stanza handling
  - pyxmpp2.presence: Presence XMPP stanza handling
  - pyxmpp2.resolver: DNS resolever with SRV record support.
  - pyxmpp2.sasl: SASL authentication implementaion for PyXMPP.
    - pyxmpp2.sasl.core: Base classes for PyXMPP SASL implementation.
    - pyxmpp2.sasl.digest_md5: DIGEST-MD5 authentication mechanism for PyXMPP SASL implementation.
    - pyxmpp2.sasl.external: External SASL authentication mechanism for PyXMPP SASL implementation.
    - pyxmpp2.sasl.gssapi: GSSAPI authentication mechanism for PyXMPP SASL implementation.
    - pyxmpp2.sasl.plain: PLAIN authentication mechanism for PyXMPP SASL implementation.
  - pyxmpp2.session: IM Session establishement implementation.
  - pyxmpp2.settings: General settings container.
  - pyxmpp2.simple: Simple API for simple things like sendig messages.
  - pyxmpp2.stanza: General XMPP Stanza handling.
  - pyxmpp2.stanzapayload: XMPP payload classes.
  - pyxmpp2.stanzaprocessor: Handling of XMPP stanzas.
  - pyxmpp2.streambase: Core XMPP stream functionality.
  - pyxmpp2.streamevents: XMPP stream events.
  - pyxmpp2.streamsasl: SASL support XMPP streams.
  - pyxmpp2.streamtls: TLS support for XMPP streams.
  - pyxmpp2.transport: XMPP transport.
  - pyxmpp2.utils: Utility functions for the pyxmpp package.
  - pyxmpp2.version
  - pyxmpp2.xmppparser: ElementTree-based XMPP stream parserg
  - pyxmpp2.xmppserializer: XMPP serializer for ElementTree data.
  - pyxmpp2.xmppstringprep: Nodeprep and resourceprep stringprep profiles.